@@ -9,9 +9,7 @@ from grai_source_postgres.loader import PostgresConnector
 from grai_source_postgres.package_definitions import config
 
 
-def get_nodes_and_edges(
-    connector: PostgresConnector, version: Literal["v1"]
-) -> Tuple[List[Node], List[Edge]]:
+def get_nodes_and_edges(connector: PostgresConnector, version: Literal["v1"]) -> Tuple[List[Node], List[Edge]]:
     with connector.connect() as conn:
         nodes, edges = conn.get_nodes_and_edges()
 
@@ -29,9 +27,13 @@ def update_server(
     host: Optional[str] = None,
     port: Optional[str] = None,
 ):
-
     conn = PostgresConnector(
-        dbname=dbname, user=user, password=password, host=host, port=port, namespace=namespace
+        dbname=dbname,
+        user=user,
+        password=password,
+        host=host,
+        port=port,
+        namespace=namespace,
     )
     nodes, edges = get_nodes_and_edges(conn, client.id)
     update(client, nodes)
